@@ -15,3 +15,5 @@ def read_asset(*paths):
 
 VERSION = read_asset("VERSION")
 LAYOUT = read_asset("templates", "layout.html")
+TABLE = read_asset("templates", "table.html")
+CHART = read_asset("templates", "chart.html")
