@@ -2,7 +2,8 @@ import yaml
 import marko
 import subprocess
 from jinja2 import Template
-from .renderer import LivemarkRenderer
+from marko.ext.gfm import GFM
+from .renderer import LivemarkExtension
 from . import config
 
 
@@ -13,17 +14,15 @@ class Document:
     # Process
 
     def process(self):
-        markdown = marko.Markdown(renderer=LivemarkRenderer)
+        markdown = marko.Markdown()
+        markdown.use(GFM)
+        markdown.use(LivemarkExtension)
 
         # Source document
         with open(self.__path) as file:
             source = file.read()
             target = source
 
-        # Preprocess document
-        template = Template(target, trim_blocks=True)
-        target = template.render()
-
         # Parse document
         metadata = {}
         if target.startswith("---"):
@@ -34,13 +33,13 @@ class Document:
         for code in metadata.get("prepare", []):
             subprocess.run(code, shell=True)
 
+        # Preprocess document
+        template = Template(target, trim_blocks=True)
+        target = template.render()
+
         # Convert document
         target = markdown.convert(target).strip()
 
-        # Cleanup document
-        for code in metadata.get("cleanup", []):
-            subprocess.run(code, shell=True)
-
         # Postprocess document
         layout = config.LAYOUT
         if metadata.get("layout"):
@@ -49,4 +48,8 @@ class Document:
         template = Template(layout)
         target = template.render(title=metadata.get("title", "Livemark"), content=target)
 
+        # Cleanup document
+        for code in metadata.get("cleanup", []):
+            subprocess.run(code, shell=True)
+
         return source, target
